@@ -1,3 +1,9 @@
+__title__ = 'werewolf.views'
+__version__ = '0.2'
+__build__ = 0x000002
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__all__ = ('autodiscover',)
+
 import imp
 
 from django.conf import settings
