@@ -1,3 +1,9 @@
+__title__ = 'werewolf.defaults'
+__version__ = '0.2'
+__build__ = 0x000002
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__all__ = ('STATUS_CHOICES', 'STATUS_PUBLISHED', 'DEFAULT_STATUS', 'STATUS_MAX_LENGTH', 'USE_DJANGO_REVERSION')
+
 gettext = lambda s: s
 
 # Status choices for the workflow. When customizing pay extra attention to `STATUS_PUBLISHED` and `DEFAULT_STATUS`
