@@ -1,3 +1,7 @@
+__title__ = 'werewolf.helpers'
+__version__ = '0.2'
+__build__ = 0x000002
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __all__ = ('admin_edit_url', 'admin_edit_url_for_object')
 
 from django.core.urlresolvers import reverse
